@@ -629,8 +629,11 @@ class DistributeEventConst(object):
         },
         SERVICESTORE_PICK_UP: {
             DistributeEventConstKey.FROM_STATUS_LIST_KEY: [
-                DistributeStatus.INIT, DistributeStatus.PRINTED,
-                DistributeStatus.CUSSERVICE_PICKED_UP, DistributeStatus.SERVICE_DESK],
+                DistributeStatus.INIT, 
+                DistributeStatus.PRINTED,
+                DistributeStatus.CUSSERVICE_PICKED_UP, 
+                DistributeStatus.SERVICE_DESK,
+                DistributeStatus.SERVICE_STOP],
             DistributeEventConstKey.TO_STATUS_KEY: DistributeStatus.SERVICE_STORE,
         },
         SERVICEDESK_PICK_UP: {
